@@ -13,6 +13,7 @@
 #undef HAVE_IODBC
 #undef SOLID_ODBC
 #undef UNIX
+#undef HAVE_ODBC
 #undef HAVE_LDAP
 #undef HAVE_MYSQL
 #undef GDA_MAJOR
@@ -22,6 +23,9 @@
 #undef HAVE_GTKSHEET
 #undef HAVE_SYBASE
 #undef HAVE_ORACLE
+#undef HAVE_INTERBASE
+#undef HAVE_BONOBO
+#undef HAVE_LIBGLADE
 /*
  * Backward compatibility
  */
