@@ -17,6 +17,7 @@
  */
 
 #include "gdafe.h"
+#include <unistd.h>
 
 static void add_environ_cb      (GtkButton *button, gpointer data);
 static void clear_text_cb       (GtkWidget *w, gpointer data);
@@ -27,18 +28,16 @@ static void font_set_cb         (GnomeFontPicker *fontpicker, gchar *font_name,
 static void remove_environ_cb   (GtkButton *button, gpointer data);
 static void save_as_cb          (GtkWidget *w, gpointer data);
 static void save_config_cb      (GtkWidget *w, gpointer data);
-static void save_dsn_cb         (GtkWidget *w, gpointer data);
 static void save_on_exit_cb     (GtkCheckButton *button, gpointer data);
 static void set_language_cb     (GtkEntry *entry, gpointer data);
 static void set_shell_cb        (GtkEntry *entry, gpointer data);
 static void set_tabs_cb         (GtkToggleButton *button, gpointer data);
 
 static GtkWidget* config_create_tab (void);
-static GtkWidget* dsn_create_tab (void);
 static GtkWidget* environ_create_tab (void);
 static GtkWidget* general_create_tab (void);
 
-extern char **environ;
+char **environ = 0;
 static GtkWidget* l_dialog = 0;
 static GtkWidget* l_notebook = 0;
 static struct
@@ -49,8 +48,7 @@ static struct
 {
   { general_create_tab, N_("General") },
   { environ_create_tab, N_("Environment") },
-  { config_create_tab, N_("Config File") },
-  { dsn_create_tab, N_("Data Sources") }
+  { config_create_tab, N_("Config File") }
 };
 
 /*
@@ -92,61 +90,14 @@ config_create_tab (void)
   gtk_box_pack_start(GTK_BOX(box), button, 0, 0, 0);
   gtk_widget_show(box);
   gtk_table_attach(GTK_TABLE(table), box, 2, 3, 0, 1,
-                   GTK_FILL,
-                   GTK_FILL,
+                   GTK_SHRINK,
+                   GTK_SHRINK,
                    3, 3);
                    
   gtk_widget_show(table);
   return (table);
 }
 
-static GtkWidget *
-dsn_create_tab (void)
-{
-  GtkWidget *table, *scroll, *text, *box, *button;
-  gchar *str;
-  
-  table = gtk_table_new(3, 3, FALSE);
-
-  /* add editor */
-  scroll = gda_ui_new_scrolled_window_widget();
-  text = fe_new_text_widget();
-  str = g_strdup_printf("%s/.gnome/gdalib", g_get_home_dir());
-  fe_load_file_in_text(GTK_TEXT(text), str);
-  g_free((gpointer) str);
-  gtk_container_add(GTK_CONTAINER(scroll), text);
-  gtk_table_attach(GTK_TABLE(table), scroll, 0, 2, 0, 3,
-                   GTK_FILL | GTK_EXPAND | GTK_SHRINK,
-                   GTK_FILL | GTK_EXPAND | GTK_SHRINK,
-                   3, 3);
-                   
-  /* add buttons */
-  box = gtk_vbox_new(TRUE, 0);
-  button = gda_ui_new_button_widget_with_pixmap(_("Save"), GNOME_STOCK_MENU_SAVE);
-  gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                     GTK_SIGNAL_FUNC(save_dsn_cb), (gpointer) text);
-  gtk_box_pack_start(GTK_BOX(box), button, 0, 0, 0);
-  button = gda_ui_new_button_widget_with_pixmap(_("Save As"), GNOME_STOCK_MENU_SAVE_AS);
-  gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                     GTK_SIGNAL_FUNC(save_as_cb), (gpointer) text);
-  gtk_box_pack_start(GTK_BOX(box), button, 0, 0, 0);
-  button = gda_ui_new_button_widget_with_pixmap(_("Clear"), GNOME_STOCK_MENU_TRASH);
-  gtk_signal_connect(GTK_OBJECT(button), "clicked",
-                     GTK_SIGNAL_FUNC(clear_text_cb), (gpointer) text);
-  gtk_box_pack_start(GTK_BOX(box), button, 0, 0, 0);
-  gtk_widget_show(box);
-  gtk_table_attach(GTK_TABLE(table), box, 2, 3, 0, 1,
-                   GTK_FILL,
-                   GTK_FILL,
-                   3, 3);
-                   
-  gtk_widget_show(table);
-  return (table);
-  
-  gtk_widget_show(table);
-  return (table);
-}
-
 static GtkWidget *
 environ_create_tab (void)
 {
@@ -174,11 +125,6 @@ environ_create_tab (void)
                    
   /* add buttons */
   box = gtk_vbox_new(TRUE, 0);
-  gtk_widget_show(box);
-  gtk_table_attach(GTK_TABLE(table), box, 2, 3, 0, 1,
-                   GTK_FILL,
-                   GTK_FILL,
-                   3, 3);
   button = gda_ui_new_button_widget_with_pixmap(_("Add"), GNOME_STOCK_MENU_NEW);
   gtk_signal_connect(GTK_OBJECT(button), "clicked",
                      GTK_SIGNAL_FUNC(add_environ_cb), (gpointer) list);
@@ -191,7 +137,12 @@ environ_create_tab (void)
   gtk_signal_connect(GTK_OBJECT(button), "clicked",
                      GTK_SIGNAL_FUNC(current_environ_cb), 0);
   gtk_box_pack_start(GTK_BOX(box), button, 0, 0, 0);
-                   
+  gtk_widget_show(box);
+  gtk_table_attach(GTK_TABLE(table), box, 2, 3, 0, 1,
+                   GTK_SHRINK,
+                   GTK_SHRINK,
+                   3, 3);
+
   gtk_widget_show(table);
   return (table);
 }
@@ -202,7 +153,7 @@ general_create_tab (void)
   GtkWidget *table, *label, *box, *entry, *button;
   int i;
   
-  table = gtk_table_new(5, 4, FALSE);
+  table = gtk_table_new(7, 2, FALSE); // era 5, 4
   
   /* on/off options */
   box = gtk_vbox_new(FALSE, 0);
@@ -234,12 +185,12 @@ general_create_tab (void)
   gtk_entry_set_text(GTK_ENTRY(entry),
                      gnome_config_get_string(FE_CONFIG_GENERAL_EDITOR_FONT));
   gtk_object_set_data(GTK_OBJECT(entry), "FE_Config_Font", FE_CONFIG_GENERAL_EDITOR_FONT);
-  gtk_box_pack_start(GTK_BOX(box), entry, 0, 0, GNOME_PAD);
+  gtk_box_pack_start(GTK_BOX(box), entry, 0, 0, 0);
   button = gnome_font_picker_new();
   gtk_signal_connect(GTK_OBJECT(button), "font-set",
                      GTK_SIGNAL_FUNC(font_set_cb), (gpointer) entry);
   gtk_widget_show(button);
-  gtk_box_pack_start(GTK_BOX(box), button, 0, 0, GNOME_PAD);
+  gtk_box_pack_start(GTK_BOX(box), button, 0, 0, 0);
   gtk_widget_show(box);
   gtk_table_attach(GTK_TABLE(table), box, 1, 2, 1, 2,
                    GTK_FILL,
@@ -254,12 +205,12 @@ general_create_tab (void)
   gtk_entry_set_text(GTK_ENTRY(entry),
                      gnome_config_get_string(FE_CONFIG_GENERAL_GRID_FONT));
   gtk_object_set_data(GTK_OBJECT(entry), "FE_Config_Font", FE_CONFIG_GENERAL_GRID_FONT);
-  gtk_box_pack_start(GTK_BOX(box), entry, 0, 0, GNOME_PAD);
+  gtk_box_pack_start(GTK_BOX(box), entry, 0, 0, 0);
   button = gnome_font_picker_new();
   gtk_signal_connect(GTK_OBJECT(button), "font-set",
                      GTK_SIGNAL_FUNC(font_set_cb), (gpointer) entry);
   gtk_widget_show(button);
-  gtk_box_pack_start(GTK_BOX(box), button, 0, 0, GNOME_PAD);
+  gtk_box_pack_start(GTK_BOX(box), button, 0, 0, 0);
   gtk_widget_show(box);
   gtk_table_attach(GTK_TABLE(table), box, 1, 2, 2, 3,
                    GTK_FILL,
@@ -268,7 +219,7 @@ general_create_tab (void)
   /* language */
   box = gtk_hbox_new(FALSE, 0);
   label = gda_ui_new_label_widget(_("Language"));
-  gtk_table_attach(GTK_TABLE(table), label, 2, 3, 1, 2,
+  gtk_table_attach(GTK_TABLE(table), label, 0, 1, 3, 4,
                    GTK_FILL,
                    GTK_FILL, 3, 3);
   button = gda_ui_new_combo_widget();
@@ -280,14 +231,14 @@ general_create_tab (void)
                      GTK_SIGNAL_FUNC(set_language_cb), NULL);
   gtk_box_pack_start(GTK_BOX(box), button, 0, 0, 0);
   gtk_widget_show(box);
-  gtk_table_attach(GTK_TABLE(table), box, 3, 4, 1, 2,
+  gtk_table_attach(GTK_TABLE(table), box, 1, 2, 3, 4,
                    GTK_FILL,
                    GTK_FILL,
                    3, 3);
                    
   /* shell */
   label = gda_ui_new_label_widget(_("Shell"));
-  gtk_table_attach(GTK_TABLE(table), label, 2, 3, 2, 3,
+  gtk_table_attach(GTK_TABLE(table), label, 0, 1, 4, 5,
                    GTK_FILL,
                    GTK_FILL, 3, 3);
   entry = gda_ui_new_file_entry_widget("FE_Config_shell_history");
@@ -296,13 +247,13 @@ general_create_tab (void)
   gtk_signal_connect(GTK_OBJECT(gnome_file_entry_gtk_entry(GNOME_FILE_ENTRY(entry))),
                      "changed",
                      GTK_SIGNAL_FUNC(set_shell_cb), 0);
-  gtk_table_attach(GTK_TABLE(table), entry, 3, 4, 2, 3,
+  gtk_table_attach(GTK_TABLE(table), entry, 1, 2, 4, 5,
                    GTK_FILL,
                    GTK_FILL, 3, 3);
              
   /* window tabs */
   label = gda_ui_new_label_widget(_("Tabs position"));
-  gtk_table_attach(GTK_TABLE(table), label, 0, 1, 3, 4,
+  gtk_table_attach(GTK_TABLE(table), label, 0, 1, 5, 6,
                    GTK_FILL,
                    GTK_FILL, 3, 3);
 
@@ -346,7 +297,7 @@ general_create_tab (void)
     }
   gtk_box_pack_start(GTK_BOX(box), button, 0, 0, 0);
 
-  gtk_table_attach(GTK_TABLE(table), box, 1, 4, 3, 4,
+  gtk_table_attach(GTK_TABLE(table), box, 1, 2, 5, 6,
                    GTK_FILL | GTK_SHRINK | GTK_EXPAND,
                    GTK_FILL | GTK_SHRINK | GTK_EXPAND,
                    3, 3);
@@ -453,6 +404,7 @@ current_environ_cb (GtkButton *button, gpointer data)
   GtkWidget *dialog, *list, *scroll;
   const gchar *cols[] = { N_("Variable"), N_("Value") };
   gchar *row[2];
+  gchar** ptr;
   register gint cnt;
   
   /* create dialog */
@@ -465,9 +417,19 @@ current_environ_cb (GtkButton *button, gpointer data)
   gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), scroll, 1, 1, GNOME_PAD);
   
   /* fill environment list */
-  for (cnt = 0; cnt < sizeof(environ) / sizeof(environ[0]); cnt++)
+  gtk_clist_freeze(GTK_CLIST(list));
+  for (ptr = environ; ptr; ptr++)
     {
+      gchar* empty_string = "";
+
+      row[0] = ptr ? ptr : empty_string;
+      row[1] = g_getenv(ptr);
+      if (!row[1]) row[1] = empty_string;
+
+      gtk_clist_append(GTK_CLIST(list), (const gchar **) row);
     }
+  gtk_clist_thaw(GTK_CLIST(list));
+
   /* run dialog and finish */
   gnome_dialog_run_and_close(GNOME_DIALOG(dialog));
 }
@@ -562,19 +524,6 @@ save_config_cb (GtkWidget *w, gpointer data)
   g_free((gpointer) str);
 }
 
-static void
-save_dsn_cb (GtkWidget *w, gpointer data)
-{
-  GtkWidget *text = (GtkWidget *) data;
-  gchar *str;
-  
-  g_return_if_fail(GTK_IS_TEXT(text));
-
-  str = g_strdup_printf("%s/.gnome/gdalib", g_get_home_dir());
-  fe_save_text_to_file(GTK_TEXT(text), str);
-  g_free((gpointer) str);
-}
-
 static void
 save_on_exit_cb (GtkCheckButton *button, gpointer data)
 {
