@@ -75,20 +75,7 @@ main (gint argc, gchar *argv[])
 static void 
 about_cb (GtkWidget *w, gpointer data)
 {
-  const gchar *authors[] = { "Michael Lausch <michael@lausch.at>",
-                             "Rodrigo Moya <rmoya@chez.com>",
-                             "Stephan Heinze <stephan.heinze@xcom.de>",
-                             "Vivien Malerba <malerba@linuxbox.com>",
-                             NULL };
-  GtkWidget *about = gnome_about_new(_("GNOME-DB Front End"), VERSION,
-	     _("Copyright The Free Software Foundation (C) 1998-2000"),
-	     authors,
-             _("This program is part of the GNOME project for LINUX. "
-	       "GNOME Data Access comes with ABSOLUTELY NO WARRANTY. "
-	       "This is free software, and you are welcome to redistribute "
-	       "it under the conditions of the GNU General Public Licence."),
-	     "gnome-db.png");
-  gtk_widget_show(about);
+  gda_ui_show_about_dialog(_("GNOME-DB Front End"));
 }
 
 static void
@@ -169,9 +156,7 @@ GnomeUIInfo filemenu[] =
     fe_disconnect_all, NULL, NULL, GNOME_APP_PIXMAP_STOCK, 
     GNOME_STOCK_MENU_STOP, 0, 0, NULL },
   GNOMEUIINFO_SEPARATOR,
-  { GNOME_APP_UI_ITEM, N_("Printer setup..."), N_("Open printer setup dialog"),
-    gda_ui_print_setup_dlg_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, 
-    GNOME_STOCK_MENU_PRINT, 0, 0, NULL },
+  GNOMEUIINFO_MENU_PRINT_SETUP_ITEM(gda_ui_print_setup_dlg_cb, NULL),
   GNOMEUIINFO_SEPARATOR,
   { GNOME_APP_UI_ITEM, N_("Quit"), N_("Exit application"),
     quit_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_QUIT,
@@ -223,7 +208,6 @@ GnomeUIInfo toolsmenu[] =
   { GNOME_APP_UI_ITEM, N_("GDA logs"), N_("View GDA server log files"),
     fe_open_log, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
     GNOME_STOCK_MENU_BOOK_RED, 0, 0, NULL },
-  GNOMEUIINFO_SEPARATOR,
   { GNOME_APP_UI_ITEM, N_("Text editor"), N_("Open the internal text editor"),
     fe_open_editor, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
     GNOME_STOCK_MENU_PREF, 0, 0, NULL },
@@ -233,6 +217,13 @@ GnomeUIInfo toolsmenu[] =
   { GNOME_APP_UI_ITEM, N_("Calculator"), N_("Open desktop calculator"),
     fe_util_calculator, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
     GNOME_STOCK_MENU_SCORES, 0, 0, NULL },
+  GNOMEUIINFO_SEPARATOR,
+  { GNOME_APP_UI_ITEM, N_("GDA Manager"), N_("The GDA configuration tool"),
+    fe_run_app, "gda-mgr", NULL, GNOME_APP_PIXMAP_NONE,
+    NULL, 0, 0, NULL },
+  { GNOME_APP_UI_ITEM, N_("GDA Builder"), N_("The GDA development environment"),
+    fe_run_app, "gda-builder", NULL, GNOME_APP_PIXMAP_NONE,
+    NULL, 0, 0, NULL },
   GNOMEUIINFO_END
 };
 GnomeUIInfo optionsmenu[] =
@@ -326,7 +317,7 @@ GnomeUIInfo toolbar[] =
     fe_open_config, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
     GNOME_STOCK_MENU_PREF, 0, 0, NULL },
   GNOMEUIINFO_SEPARATOR,
-  { GNOME_APP_UI_ITEM, N_("Exit"), N_("Exit application"),
+  { GNOME_APP_UI_ITEM, N_("Quit"), N_("Exit application"),
     quit_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
     GNOME_STOCK_MENU_EXIT, 0, 0, NULL },
   GNOMEUIINFO_END
@@ -336,7 +327,7 @@ static void
 prepare_app (void)
 {
   /* create main window */
-  glb_App = GNOME_APP(gnome_app_new("gdafe", "GNOME-DB"));
+  glb_App = GNOME_APP(gnome_app_new("gdafe", "SQL Front End"));
   gtk_window_set_policy(GTK_WINDOW(glb_App), TRUE, TRUE, FALSE);
   gtk_widget_realize(GTK_WIDGET(glb_App));
   gtk_signal_connect(GTK_OBJECT(glb_App), "delete_event",
