@@ -42,4 +42,16 @@ fe_util_calculator (GtkWidget *w, gpointer data)
       gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(l_CalcDialog)->vbox), calc, 1, 1, 0);
     }
   gtk_widget_show(l_CalcDialog);
+}
+
+void
+fe_run_app (GtkWidget *w, const gchar *cmd)
+{
+  gchar* args[1];
+
+  g_return_if_fail(cmd != 0);
+
+  args[0] = cmd;
+  if (gnome_execute_async(NULL, 1, args) == -1)
+    gda_ui_show_error(_("Unable to execute '%s'"), args[0]);
 }
\ No newline at end of file
