@@ -138,13 +138,14 @@ fe_add_toolbar_to_view (GtkWidget *view, gint x1, gint y1, gint x2, gint y2, Gno
   table = (GtkWidget *) gtk_object_get_data(GTK_OBJECT(view), "FE_View_TableWidget");
   g_return_if_fail(GTK_IS_TABLE(table));
   
-  toolbar = gtk_toolbar_new(GTK_ORIENTATION_HORIZONTAL, GTK_TOOLBAR_ICONS);
+  toolbar = gda_ui_new_toolbar_widget(GTK_ORIENTATION_HORIZONTAL,
+				      GTK_TOOLBAR_ICONS,
+				      data,
+                                      NULL);
   gtk_table_attach(GTK_TABLE(table), toolbar, x1, x2, y1, y2,
                    GTK_SHRINK | GTK_FILL,
                    GTK_FILL,
                    3, 3);
-  gnome_app_fill_toolbar(GTK_TOOLBAR(toolbar), data, NULL);
-  gtk_widget_show(toolbar);
 
   fe_set_view_data(view, "FE_View_Toolbar", (gpointer) toolbar);
 }
