@@ -24,10 +24,6 @@
 #endif
 
 #include <gnome.h>
-#include <gda.h>
-#include <gda-connection.h>
-#include <gda-server.h>
-#include <gda-xml.h>
 #include <gda-ui.h>
 
 /*
@@ -134,6 +130,7 @@ extern void fe_open_gda_config (GtkWidget *w, gpointer data);
 extern void fe_open_import     (GtkWidget *w, gpointer data);
 extern void fe_open_log        (GtkWidget *w, gpointer data);
 extern void fe_open_designer   (GtkWidget *w, gpointer data);
+extern void fe_run_app         (GtkWidget *w, const gchar *cmd);
 extern void fe_run_shell       (GtkWidget *w, gpointer data);
 extern void fe_util_calculator (GtkWidget *w, gpointer data);
 
@@ -145,7 +142,7 @@ extern CORBA_ORB  glb_Orb;				/* CORBA connection */
 extern GtkWidget* glb_WorkArea;			/* notebook */
 extern GtkWidget* glb_StatusBar;        /* status bar */
 extern GdkFont*   glb_EditorFont;       /* editor font */
-extern GdkFont*   glb_GridFont;         /* 
+extern GdkFont*   glb_GridFont;         /* grid font */
 
 /*
  * Configuration files strings
