@@ -65,16 +65,18 @@ browse_data_cb (GtkWidget *w, gpointer data)
           
       if (str != 0)
 	{
-	  GtkWidget *dialog, *table, *grid, *label, *entry;
+	  GtkWidget *dialog, *frame, *table, *grid, *label, *entry;
 	  gulong reccount;
 	  Gda_Recordset *recset;
               
 	  dialog = gnome_dialog_new(name, GNOME_STOCK_BUTTON_CLOSE, NULL);
 	  gtk_widget_set_usize(dialog, 600, 450);
+          frame = gda_ui_new_frame_widget(NULL);
+	  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), frame, 1, 1, 0);
               
 	  table = gtk_table_new(4, 2, FALSE);
 	  gtk_widget_show(table);
-	  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), table, 0, 0, 0);
+          gtk_container_add(GTK_CONTAINER(frame), table);
 
           label = gda_ui_new_label_widget(_("Object Name"));
 	  gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,
@@ -89,13 +91,15 @@ browse_data_cb (GtkWidget *w, gpointer data)
                            GTK_FILL,
 			       3, 3);
 
-	  grid = gnome_db_grid_new(0);
-	  gtk_widget_show(grid);
-	  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), grid, 1, 1, 0);
+	  grid = gda_ui_new_grid_widget(NULL);
+          gtk_table_attach(GTK_TABLE(table), grid, 0, 2, 1, 3,
+                           GTK_FILL | GTK_EXPAND | GTK_SHRINK,
+                           GTK_FILL | GTK_EXPAND | GTK_SHRINK,
+                           3, 3);
 
 	  label = gda_ui_new_label_widget(_("0 rows"));
 	  gtk_misc_set_alignment(GTK_MISC(label), 0.5, 0.5);
-	  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), label, 0, 0, 0);
+          gtk_table_attach(GTK_TABLE(table), label, 0, 2, 3, 4, GTK_FILL, GTK_FILL, 3, 3);
 	  gtk_signal_connect(GTK_OBJECT(grid), "loaded",
 			     GTK_SIGNAL_FUNC(browse_data_loaded_cb), (gpointer) label);
               
@@ -381,33 +385,34 @@ gnome_db_browser_class_init (GnomeDbBrowserClass *klass)
 static void
 gnome_db_browser_init (GnomeDbBrowser *brw)
 {
+  GtkWidget *frame;
   GtkWidget *table;
   GtkWidget *box;
   GtkWidget *button;
   
-  table = gtk_table_new(5, 8, FALSE);
-  gtk_box_pack_start(GTK_BOX(brw), table, 1, 1, 0);
+  frame = gda_ui_new_frame_widget(NULL);
+  gtk_box_pack_start(GTK_BOX(brw), frame, 1, 1, 0);
+  table = gtk_table_new(5, 4, FALSE);
+  gtk_container_add(GTK_CONTAINER(frame), table);
   gtk_widget_show(table);
   
   brw->object_list = gnome_db_icon_list_new(0, 0);
   gtk_signal_connect(GTK_OBJECT(brw->object_list), "select_row",
                      GTK_SIGNAL_FUNC(select_object_cb), (gpointer) brw);
   gtk_widget_show(brw->object_list);
-  gtk_table_attach(GTK_TABLE(table), brw->object_list, 0, 6, 0, 1,
-                   GTK_FILL | GTK_EXPAND | GTK_SHRINK,
+  gtk_table_attach(GTK_TABLE(table), brw->object_list, 0, 1, 0, 5,
                    GTK_FILL | GTK_EXPAND | GTK_SHRINK,
+                   GTK_FILL,
                    3, 3);
 
-  brw->object_description = gnome_db_grid_new(0);
-  gnome_db_grid_hide_row_numbers(GNOME_DB_GRID(brw->object_description));
-  gtk_widget_show(brw->object_description);
-  gtk_table_attach(GTK_TABLE(table), brw->object_description, 0, 8, 1, 5,
+  brw->object_description = gda_ui_new_grid_widget(NULL);
+  gtk_table_attach(GTK_TABLE(table), brw->object_description, 1, 4, 1, 4,
                    GTK_FILL | GTK_EXPAND | GTK_SHRINK,
                    GTK_FILL | GTK_EXPAND | GTK_SHRINK,
                    3, 3);
   
   /* create tabs */                 
-  box = gtk_vbox_new(FALSE, 0);
+  box = gtk_hbox_new(FALSE, 0);
   brw->tables_button = gtk_radio_button_new_with_label(0, _("Tables"));
   gtk_signal_connect(GTK_OBJECT(brw->tables_button), "toggled",
                      GTK_SIGNAL_FUNC(show_tables_cb), (gpointer) brw);
@@ -446,19 +451,13 @@ gnome_db_browser_init (GnomeDbBrowser *brw)
   gtk_widget_show(brw->aggrs_button);
   gtk_box_pack_start(GTK_BOX(box), brw->aggrs_button, 0, 0, 0);
   
-  gtk_table_attach(GTK_TABLE(table), box, 6, 7, 0, 1,
-                   GTK_SHRINK, 
-                   GTK_FILL,
-                   3, 3);
+  gtk_table_attach(GTK_TABLE(table), box, 1, 4, 0, 1, GTK_FILL, GTK_FILL, 1, 1);
   gtk_widget_show(box);
   
-  /* create right button bar */
-  box = gtk_vbox_new(FALSE, 0);
+  /* create button bar */
+  box = gtk_hbox_new(TRUE, 0);
   gtk_widget_show(box);
-  gtk_table_attach(GTK_TABLE(table), box, 7, 8, 0, 1,
-                   GTK_SHRINK,
-                   GTK_FILL,
-                   3, 3);
+  gtk_table_attach(GTK_TABLE(table), box, 1, 4, 4, 5, GTK_FILL, GTK_FILL, 1, 1);
                    
   button = gnome_pixmap_button(gnome_stock_new_with_icon(GNOME_STOCK_MENU_PROP),
                                _("Data"));
