@@ -54,6 +54,18 @@ copy_cb (GtkWidget *w, gpointer data)
 {
 }
 
+static void
+drag_data_get_cb (GtkWidget *w,
+		  GdkDragContext *context,
+		  GtkSelectionData *selection_data,
+		  guint info,
+		  guint time)
+{
+  g_return_if_fail(GTK_IS_CLIST(w));
+
+  /* FIXME: how to send the grid contents? */
+}
+
 static void
 select_all_cb (GtkWidget *w, gpointer data)
 {
@@ -69,7 +81,7 @@ select_row_cb (GtkCList *clist, gint row, gint column, GdkEvent *event, gpointer
   g_return_if_fail(GNOME_DB_IS_GRID(data));
   
   grid = GNOME_DB_GRID(data);
-  gtk_signal_emit(GTK_OBJECT(grid), gnome_db_grid_signals[GNOME_DB_GRID_SELECT_ROW], row);
+  gtk_signal_emit(GTK_OBJECT(grid), gnome_db_grid_signals[GNOME_DB_GRID_SELECT_ROW], row + 1);
 }
 
 static void
@@ -80,7 +92,7 @@ unselect_row_cb (GtkCList *clist, gint row, gint column, GdkEvent *event, gpoint
   g_return_if_fail(GNOME_DB_IS_GRID(data));
   
   grid = GNOME_DB_GRID(data);
-  gtk_signal_emit(GTK_OBJECT(grid), gnome_db_grid_signals[GNOME_DB_GRID_UNSELECT_ROW], row);
+  gtk_signal_emit(GTK_OBJECT(grid), gnome_db_grid_signals[GNOME_DB_GRID_UNSELECT_ROW], row + 1);
 }
 
 static void
@@ -124,6 +136,22 @@ show_row_numbers_cb (GtkWidget *w, gpointer data)
   g_return_if_fail(GNOME_DB_IS_GRID(grid));
 }
 
+static void
+view_as_records_cb (GtkWidget *w, gpointer data)
+{
+  GtkWidget* dialog;
+  GtkWidget* dset;
+
+  g_return_if_fail(GNOME_DB_IS_GRID(data));
+
+  dialog = gnome_dialog_new(_("Record View"), GNOME_STOCK_BUTTON_CLOSE, NULL);
+  dset = gnome_db_dataset_new(gnome_db_grid_get_recordset(GNOME_DB_GRID(data)));
+  gtk_widget_show(dset);
+  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), dset, 1, 1, 0);
+
+  gnome_dialog_run_and_close(GNOME_DIALOG(dialog));
+}
+
 /*
  * Signal handlers
  */
@@ -146,8 +174,8 @@ GnomeUIInfo gridpopupmenu[] =
   { GNOME_APP_UI_ITEM, N_("Clear selection"), N_("Clear all selected rows"),
     clear_selection_cb, NULL, NULL, GNOME_APP_PIXMAP_NONE,
     NULL, 0, 0, NULL },
-  { GNOME_APP_UI_ITEM, N_("Edit current row..."), N_("Edit currently selected row"),
-    NULL, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+  { GNOME_APP_UI_ITEM, N_("Record view..."), N_("View recordset record-by-record"),
+    view_as_records_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
     GNOME_STOCK_MENU_FONT, 0, 0, NULL },
   GNOMEUIINFO_SEPARATOR,
   { GNOME_APP_UI_ITEM, N_("Refresh grid"), N_("Refresh grid contents"),
@@ -172,14 +200,27 @@ create_grid (gint cnt, gchar *titles[], GnomeDbGrid *parent)
 
   /* create widget */
   grid = gda_ui_new_clist_widget(titles, cnt);
+  if (parent->show_col_names)
+    gtk_clist_column_titles_show(GTK_CLIST(parent->grid));
+  else gtk_clist_column_titles_hide(GTK_CLIST(parent->grid));
+
   gtk_clist_set_selection_mode(GTK_CLIST(grid), GTK_SELECTION_MULTIPLE);
-  gtk_signal_connect(GTK_OBJECT(grid), "select_row",
-                     GTK_SIGNAL_FUNC(select_row_cb), (gpointer) parent);
-  gtk_signal_connect(GTK_OBJECT(grid), "unselect_row",
-                     GTK_SIGNAL_FUNC(unselect_row_cb), (gpointer) parent);
-  
+  gtk_signal_connect(GTK_OBJECT(grid),
+		     "select_row",
+                     GTK_SIGNAL_FUNC(select_row_cb),
+		     (gpointer) parent);
+  gtk_signal_connect(GTK_OBJECT(grid),
+		     "unselect_row",
+                     GTK_SIGNAL_FUNC(unselect_row_cb),
+		     (gpointer) parent);
+
+  /* drag'n'drop */
+  gtk_signal_connect(GTK_OBJECT(grid),
+		     "drag_data_get",
+		     GTK_SIGNAL_FUNC(drag_data_get_cb),
+		     NULL);
+
   /* set GtkCList properties */
-    
   gtk_widget_show(grid);
   gtk_container_add(GTK_CONTAINER(parent->scrolled_window), grid);
   gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(parent->scrolled_window),
@@ -302,14 +343,19 @@ show_recordset (GnomeDbGrid *grid, Gda_Recordset *recset)
                   break;
               }
           }
+
+	grid->total_rows = 0;
+	grid->timeout_handle = gtk_timeout_add(15, (GtkFunction) timeout_callback,
+					       (gpointer) grid);
+	gtk_clist_moveto(GTK_CLIST(grid->grid), 0, 0, 0.0, 0.0);
+      }
+    else
+      {
+	create_empty_grid(grid);
+	grid->timeout_handle = -1;
       }
     g_ptr_array_free(columns, TRUE);
   }
-  
-  grid->total_rows = 0;
-  grid->timeout_handle = gtk_timeout_add(150, (GtkFunction) timeout_callback,
-                                         (gpointer) grid);
-  gtk_clist_moveto(GTK_CLIST(grid->grid), 0, 0, 0.0, 0.0);
 }
 
 /*
@@ -333,17 +379,17 @@ gnome_db_grid_class_init (GnomeDbGridClass *klass)
   gnome_db_grid_signals[GNOME_DB_GRID_SELECT_ROW] =
            gtk_signal_new("select_row", GTK_RUN_LAST, object_class->type,
                           GTK_SIGNAL_OFFSET(GnomeDbGridClass, select_row),
-                          gtk_signal_default_marshaller,
+                          gtk_marshal_NONE__INT,
                           GTK_TYPE_NONE, 1, GTK_TYPE_INT);
   gnome_db_grid_signals[GNOME_DB_GRID_UNSELECT_ROW] =
            gtk_signal_new("unselect_row", GTK_RUN_LAST, object_class->type,
                           GTK_SIGNAL_OFFSET(GnomeDbGridClass, unselect_row),
-                          gtk_signal_default_marshaller,
+                          gtk_marshal_NONE__INT,
                           GTK_TYPE_NONE, 1, GTK_TYPE_INT);
   gnome_db_grid_signals[GNOME_DB_GRID_ADD_ROW] =
            gtk_signal_new("add_row", GTK_RUN_LAST, object_class->type,
                           GTK_SIGNAL_OFFSET(GnomeDbGridClass, add_row),
-                          gtk_signal_default_marshaller,
+                          gtk_marshal_NONE__INT,
                           GTK_TYPE_NONE, 1, GTK_TYPE_INT);
   gtk_object_class_add_signals(object_class, gnome_db_grid_signals,
                                GNOME_DB_GRID_LAST_SIGNAL);
@@ -414,6 +460,7 @@ gnome_db_grid_new (Gda_Recordset *recset)
   if (recset == NULL)
     create_empty_grid(GNOME_DB_GRID(grid));
   else show_recordset(GNOME_DB_GRID(grid), recset);
+
   return (grid);
 }
 
