@@ -17,8 +17,6 @@
  */
 
 #include "gda-ui.h"
-#include "gda-error.h"
-#include "gda-server.h"
 
 enum
 {
@@ -227,47 +225,46 @@ gnome_db_login_init (GnomeDbLogin* login)
   GList*     node;
   gchar*     titles[] = { N_("GDA Name"), N_("User Name") };
 
-  table = gtk_table_new(4, 3, 0);
-  gtk_table_set_col_spacings(GTK_TABLE(table), 10);
-  gtk_table_set_row_spacings(GTK_TABLE(table), 10);
+  frame = gda_ui_new_frame_widget(NULL);
+  gtk_box_pack_start(GTK_BOX(login), frame, TRUE, TRUE, 0);
+
+  table = gda_ui_new_table_widget(3, 4, FALSE);
+  gtk_container_add(GTK_CONTAINER(frame), table);
 
   label = gda_ui_new_label_widget(_("GDA Datasource"));
-  gtk_misc_set_alignment(GTK_MISC(label), 0.1, 1.0);
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1,
-		   GTK_FILL, 0, 0, 0);
+		   GTK_FILL, 0, 3, 3);
 
   login->gda_dbname = gtk_combo_new();
-  gtk_combo_set_value_in_list(GTK_COMBO(login->gda_dbname), TRUE, FALSE);
+  //gtk_combo_set_value_in_list(GTK_COMBO(login->gda_dbname), TRUE, FALSE);
   gtk_table_attach(GTK_TABLE(table), login->gda_dbname, 1, 2, 0, 1,
-		    GTK_FILL, 0, 0, 0);
+		    GTK_FILL, 0, 3, 3);
   gtk_widget_show(login->gda_dbname);
   
   label = gda_ui_new_label_widget(_("Username"));
-  gtk_misc_set_alignment(GTK_MISC(label), 0.1, 1.0);
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,
-		   GTK_FILL, 0, 0, 0);
+		   GTK_FILL, 0, 3, 3);
   
   login->username_entry = gtk_entry_new();
   gtk_table_attach(GTK_TABLE(table), login->username_entry, 1, 2, 1, 2,
-		   GTK_FILL, 0, 0, 0);
+		   GTK_FILL, 0, 3, 3);
   gtk_widget_show(login->username_entry);
   
   label = gda_ui_new_label_widget(_("Password"));
-  gtk_misc_set_alignment(GTK_MISC(label), 0.1, 1.0);
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3,
-		   GTK_FILL, 0, 0, 0);
+		   GTK_FILL, 0, 3, 3);
   
   login->password_entry = gtk_entry_new();
   gtk_widget_show(login->password_entry);
   gtk_table_attach(GTK_TABLE(table), login->password_entry, 1, 2, 2, 3,
-		   GTK_FILL, 0, 0, 0);
+		   GTK_FILL, 0, 3, 3);
   gtk_entry_set_visibility(GTK_ENTRY(login->password_entry), FALSE);
 
   frame = gda_ui_new_frame_widget(_("Last Connections"));
   gtk_table_attach(GTK_TABLE(table), frame, 0, 3, 3, 4,
                    GTK_FILL | GTK_EXPAND | GTK_SHRINK,
                    GTK_FILL | GTK_EXPAND | GTK_SHRINK,
-                   0, 0);
+                   3, 3);
                    
   scroll = gda_ui_new_scrolled_window_widget();
   gtk_container_add(GTK_CONTAINER(frame), scroll);
@@ -293,9 +290,6 @@ gnome_db_login_init (GnomeDbLogin* login)
         }
       node = g_list_next(node);
     }
-  
-  gtk_box_pack_start(GTK_BOX(login), table, TRUE, TRUE, 0);
-  gtk_widget_show(table);
 }
 
 /**
