@@ -90,7 +90,7 @@ find_node_by_type (GnomeDbXmlViewer *viewer, const gchar *type)
 static void
 add_property_cb (GtkWidget *w, GnomeDbXmlViewer *viewer)
 {
-  GtkWidget *dialog, *table, *label, *name_entry, *value_entry;
+  GtkWidget *dialog, *table, *label, *name_entry, *value_entry, *frame;
   gint       btn;
 
   g_return_if_fail(GNOME_DB_IS_XML_VIEWER(viewer));
@@ -102,18 +102,23 @@ add_property_cb (GtkWidget *w, GnomeDbXmlViewer *viewer)
   dialog = gnome_dialog_new(_("Add Property"),
                             GNOME_STOCK_BUTTON_OK,
                             GNOME_STOCK_BUTTON_CANCEL, NULL);
+  gnome_dialog_set_default(GNOME_DIALOG(dialog), 0);
+  frame = gda_ui_new_frame_widget(NULL);
+  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), frame, 1, 1, 0);
   table = gtk_table_new(2, 2, FALSE);
   gtk_widget_show(table);
-  gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(dialog)->vbox), table, 1, 1, 0);
+  gtk_container_add(GTK_CONTAINER(frame), table);
   
   label = gda_ui_new_label_widget(_("Property"));
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 3, 3);
   name_entry = gda_ui_new_entry_widget(0, TRUE);
+  gnome_dialog_editable_enters(GNOME_DIALOG(dialog), name_entry);
   gtk_table_attach(GTK_TABLE(table), name_entry, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 3, 3);
 
   label = gda_ui_new_label_widget(_("Value"));
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 3, 3);
   value_entry = gda_ui_new_entry_widget(0, TRUE);
+  gnome_dialog_editable_enters(GNOME_DIALOG(dialog), value_entry);
   gtk_table_attach(GTK_TABLE(table), value_entry, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 3, 3);
 
   /* run the dialog */
@@ -333,16 +338,20 @@ gnome_db_xml_viewer_class_init (GnomeDbXmlViewerClass *klass)
 static void
 gnome_db_xml_viewer_init (GnomeDbXmlViewer *viewer)
 {
-  GtkWidget* box, *box2, *table, *label, *scroll, *popup_menu;
+  GtkWidget* box, *box2, *table, *label, *scroll, *popup_menu, *frame;
   const gchar* titles[] = { N_("Property"), N_("Value") };
   
+  frame = gda_ui_new_frame_widget(NULL);
+  gtk_box_pack_start(GTK_BOX(viewer), frame, 1, 1, 0);
+
   box = gtk_hbox_new(0, 0);
   gtk_widget_show(box);
-  gtk_box_pack_start(GTK_BOX(viewer), box, 1, 1, 0);
-  
+  gtk_container_add(GTK_CONTAINER(frame), box);
+  //gtk_box_pack_start(GTK_BOX(viewer), box, 1, 1, 0);
+
   /* create tree widget */
   scroll = gda_ui_new_scrolled_window_widget();
-  gtk_box_pack_start(GTK_BOX(box), scroll, 1, 1, 0);
+  gtk_box_pack_start(GTK_BOX(box), scroll, 1, 1, GNOME_PAD);
   viewer->tree = gda_ui_new_tree_widget();
   gtk_signal_connect(GTK_OBJECT(viewer->tree),
                      "select-child",
@@ -356,12 +365,15 @@ gnome_db_xml_viewer_init (GnomeDbXmlViewer *viewer)
   
   box2 = gtk_vbox_new(0, 0);
   gtk_widget_show(box2);
-  gtk_box_pack_start(GTK_BOX(box), box2, 1, 1, 0);
+  gtk_box_pack_start(GTK_BOX(box), box2, 1, 1, GNOME_PAD);
+
+  frame = gda_ui_new_frame_widget(NULL);
+  gtk_box_pack_start(GTK_BOX(box2), frame, 0, 0, GNOME_PAD);
 
   table = gtk_table_new(4, 2, FALSE);
   gtk_widget_show(table);
-  gtk_box_pack_start(GTK_BOX(box2), table, 0, 0, 0);
-  
+  gtk_container_add(GTK_CONTAINER(frame), table);
+
   label = gda_ui_new_label_widget(_("Database name"));
   gtk_table_attach(GTK_TABLE(table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 3, 3);
   viewer->dbname_entry = gda_ui_new_entry_widget(0, TRUE);
@@ -373,7 +385,7 @@ gnome_db_xml_viewer_init (GnomeDbXmlViewer *viewer)
   
   /* create object description */
   scroll = gda_ui_new_scrolled_window_widget();
-  gtk_box_pack_start(GTK_BOX(box2), scroll, 1, 1, 0);
+  gtk_box_pack_start(GTK_BOX(box2), scroll, 1, 1, GNOME_PAD);
   viewer->description = gda_ui_new_clist_widget((gchar **) titles, 
                                                 sizeof(titles) / sizeof(titles[0]));
   popup_menu = gda_ui_new_popup_menu(viewer->description, propertypopupmenu, (gpointer) viewer);
@@ -554,4 +566,4 @@ gnome_db_xml_viewer_get_selected (GnomeDbXmlViewer *viewer)
 {
   g_return_val_if_fail(GNOME_DB_IS_XML_VIEWER(viewer), 0);
   return (viewer->selected_object);
-}
\ No newline at end of file
+}
