@@ -22,9 +22,7 @@
 #include <libgnorba/gnorba.h>
 #include <gtk/gtkmarshal.h>
 
-#include <gda-connection.h>
-#include <gda-recordset.h>
-#include <gda-command.h>
+#include <gda-client.h>
 
 static GHashTable* factories = 0;
 
@@ -68,7 +66,7 @@ gda_connection_get_type (void)
     {
       GtkTypeInfo gda_connection_info =
       {
-        "GdaConnection",
+        "Gda_Connection",
         sizeof (Gda_Connection),
         sizeof (Gda_ConnectionClass),
         (GtkClassInitFunc)gda_connection_class_init,
@@ -462,8 +460,6 @@ gda_connection_open (Gda_Connection* cnc, gchar* dsn, gchar* user, gchar* pwd)
   
   g_return_val_if_fail(IS_GDA_CONNECTION(cnc), -1);
   g_return_val_if_fail(cnc->connection == CORBA_OBJECT_NIL, -1);
-  g_return_val_if_fail(user != 0, -1);
-  g_return_val_if_fail(pwd != 0, -1);
   g_return_val_if_fail(cnc->is_open == 0, -1);
 
   if (!dsn)
