@@ -17,7 +17,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <gda-connection.h>
+#include <gda-client.h>
 
 enum
 {
@@ -575,6 +575,16 @@ gda_recordset_move_next (Gda_Recordset* rs)
   return gda_recordset_move(rs, 1, 0);
 }
 
+/**
+ * gda_recordset_move_prev
+ * @rs: the recordset
+ */
+gulong
+gda_recordset_move_prev (Gda_Recordset *rs)
+{
+  return -1;
+}
+
 /**
  * gda_recordset_field_idx:
  * @rs: the recordset
