@@ -16,7 +16,7 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <gda-xml.h>
+#include <gda-client.h>
 
 enum
 {
@@ -30,6 +30,8 @@ static gint gda_xml_database_signals[GDA_XML_LAST_SIGNAL] = { 0, };
 static void gda_xml_database_init       (Gda_XmlDatabase *db);
 static void gda_xml_database_class_init (Gda_XmlDatabaseClass *klass);
 
+static void gda_xml_database_destroy    (Gda_XmlDatabase *db);
+
 /* private functions */
 static void
 database_add_object_cb (Gda_XmlDatabase *db, Gda_XmlObject *obj)
@@ -140,6 +142,7 @@ gda_xml_database_class_init (Gda_XmlDatabaseClass *klass)
   gtk_object_class_add_signals(object_class, gda_xml_database_signals,
                                GDA_XML_LAST_SIGNAL);
 
+  object_class->destroy = gda_xml_database_destroy;
   klass->changed = database_changed_cb;
   klass->add_object = database_add_object_cb;
 }
@@ -243,20 +246,13 @@ gda_xml_database_new_from_file (const gchar *filename)
   return (0);
 }
 
-/**
- * gda_xml_database_free
- * @db: a @Gda_XmlDatabase object
- *
- * Cleans up all memory associated with the XML representation of the
- * given database
- */
-void
-gda_xml_database_free (Gda_XmlDatabase *db)
+static void
+gda_xml_database_destroy (Gda_XmlDatabase *db)
 {
   GList* node;
 
   g_return_if_fail(IS_GDA_XML_DATABASE(db));
-  
+
   while ((node = g_list_first(db->objects)))
     {
       Gda_XmlObject* obj = (Gda_XmlObject *) node->data;
@@ -269,6 +265,20 @@ gda_xml_database_free (Gda_XmlDatabase *db)
   g_free((gpointer) db);
 }
 
+/**
+ * gda_xml_database_free
+ * @db: a @Gda_XmlDatabase object
+ *
+ * Cleans up all memory associated with the XML representation of the
+ * given database
+ */
+void
+gda_xml_database_free (Gda_XmlDatabase *db)
+{
+  g_return_if_fail(IS_GDA_XML_DATABASE(db));
+  gtk_object_destroy(GTK_OBJECT(db));
+}
+
 /**
  * gda_xml_database_save
  * @db: a @Gda_XmlDatabase object
