@@ -22,16 +22,15 @@
 #  define GNOMELOCALEDIR "/usr/locale"
 #endif
 
-static void about_cb    (GtkWidget *w, gpointer data);
-static void quit_cb     (GtkWidget *w, gpointer data);
+static void  run_app_cb  (GtkWidget *w, const gchar *cmd);
 
-static void prepare_app (void);
+static guint prepare_app (void);
 
 /* global variables */
-GtkWidget*      glb_App = 0;
-GtkWidget*      glb_StatusBar = 0;
-CORBA_ORB       glb_Orb;
-Gda_Connection* glb_dbconn = 0;
+GnomeDbContainer* glb_Container = 0;
+GtkWidget*        glb_Notebook = 0;
+CORBA_ORB         glb_Orb;
+Gda_Connection*   glb_dbconn = 0;
 
 /* menus */
 GnomeUIInfo filenewmenu[] =
@@ -75,8 +74,11 @@ GnomeUIInfo databasemenu[] =
     builder_database_disconnect, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
     GNOME_STOCK_MENU_STOP, 0, 0, NULL },
   GNOMEUIINFO_SEPARATOR,
+  { GNOME_APP_UI_ITEM, N_("Browse"), N_("Open database browser"),
+    builder_browse_database_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+    GNOME_STOCK_MENU_PROP, 0, 0, NULL },
   { GNOME_APP_UI_ITEM, N_("Import objects"), N_("Import database objects into repository"),
-    NULL, NULL, NULL, GNOME_APP_PIXMAP_NONE,
+    builder_database_import_objects, NULL, NULL, GNOME_APP_PIXMAP_NONE,
     NULL, 0, 0, NULL },
   GNOMEUIINFO_END
 };
@@ -86,26 +88,42 @@ GnomeUIInfo filemenu[] =
   GNOMEUIINFO_SUBTREE(N_("Open"), fileopenmenu),
   { GNOME_APP_UI_ITEM, N_("Close"), N_("Close current window"),
     NULL, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-    GNOME_STOCK_PIXMAP_CLOSE, 0, 0, NULL },
+    GNOME_STOCK_MENU_CLOSE, 0, 0, NULL },
   { GNOME_APP_UI_ITEM, N_("Close all"), N_("Close all open windows"),
     NULL, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-    GNOME_STOCK_PIXMAP_CLOSE, 0, 0, NULL },
+    GNOME_STOCK_MENU_CLOSE, 0, 0, NULL },
   GNOMEUIINFO_SEPARATOR,
-  { GNOME_APP_UI_ITEM, N_("Printer setup..."), N_("Open printer setup dialog"),
-    gda_ui_print_setup_dlg_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK, 
-    GNOME_STOCK_MENU_PRINT, 0, 0, NULL },
+  GNOMEUIINFO_MENU_PRINT_SETUP_ITEM(gda_ui_print_setup_dlg_cb, NULL),
   GNOMEUIINFO_SEPARATOR,
   { GNOME_APP_UI_ITEM, N_("Quit"), N_("Exit application"),
-    quit_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+    builder_quit_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
     GNOME_STOCK_MENU_QUIT, 0, 0, NULL },
   GNOMEUIINFO_END
 };
+GnomeUIInfo toolsmenu[] =
+{
+#if defined(HAVE_BONOBO)
+  { GNOME_APP_UI_ITEM, N_("GNOME-DB Front End"), N_("The GNOME-DB front end"),
+    run_app_cb, "gda-fe", NULL, GNOME_APP_PIXMAP_NONE,
+    NULL, 0, 0, NULL },
+#else
+  { GNOME_APP_UI_ITEM, N_("SQL Front End"), N_("The SQL front end"),
+    run_app_cb, "gdafe", NULL, GNOME_APP_PIXMAP_NONE,
+    NULL, 0, 0, NULL },
+#endif
+  { GNOME_APP_UI_ITEM, N_("GNOME-DB Manager"), N_("The GNOME-DB configuration tool"),
+    run_app_cb, "gda-mgr", NULL, GNOME_APP_PIXMAP_NONE,
+    NULL, 0, 0, NULL },
+  GNOMEUIINFO_END
+};
 GnomeUIInfo helpmenu[] =
 {
+#if !defined(HAVE_BONOBO)
   GNOMEUIINFO_HELP("gnome-db"),
   GNOMEUIINFO_SEPARATOR,
+#endif
   { GNOME_APP_UI_ITEM, N_("About gnome-db..."), N_("About this program"),
-    about_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+    builder_about_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
     GNOME_STOCK_MENU_ABOUT, 0, 0, NULL },
   GNOMEUIINFO_END
 };
@@ -113,6 +131,7 @@ GnomeUIInfo mainmenu[] =
 {
   GNOMEUIINFO_SUBTREE(N_("File"), filemenu),
   GNOMEUIINFO_SUBTREE(N_("Database"), databasemenu),
+  GNOMEUIINFO_SUBTREE(N_("Tools"), toolsmenu),
   GNOMEUIINFO_SUBTREE(N_("Help"), helpmenu),
   GNOMEUIINFO_END
 };
@@ -127,18 +146,12 @@ GnomeUIInfo toolbar[] =
     0, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
     GNOME_STOCK_MENU_OPEN, 0, 0, NULL },
   GNOMEUIINFO_SEPARATOR,
-  { GNOME_APP_UI_ITEM, N_("Previous"), N_("Move to previous window on list"),
-    0, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-    GNOME_STOCK_MENU_BACK, 0, 0, NULL },
-  { GNOME_APP_UI_ITEM, N_("Next"), N_("Move to next window on list"),
-    0, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
-    GNOME_STOCK_MENU_FORWARD, 0, 0, NULL },
   { GNOME_APP_UI_ITEM, N_("Preferences"), N_("Configure user preferences"),
     0, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
     GNOME_STOCK_MENU_PREF, 0, 0, NULL },
   GNOMEUIINFO_SEPARATOR,
   { GNOME_APP_UI_ITEM, N_("Quit"), N_("Exit application"),
-    quit_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
+    builder_quit_cb, NULL, NULL, GNOME_APP_PIXMAP_STOCK,
     GNOME_STOCK_MENU_EXIT, 0, 0, NULL },
   GNOMEUIINFO_END
 };
@@ -169,73 +182,79 @@ main (gint argc, gchar *argv[])
   bindtextdomain(PACKAGE, GNOMELOCALEDIR);
   textdomain(PACKAGE);
 
-  /* initialize CORBA stuff */
+  /* initialize CORBA/Bonobo stuff */
   CORBA_exception_init(&ev);
   glb_Orb = gnome_CORBA_init("gda-builder", VERSION, &argc, argv, 0, &ev);
   Exception(&ev);
 
-  /* load application settings and create main window */
-  prepare_app();
+  if (bonobo_init(glb_Orb, NULL, NULL) == FALSE)
+    g_error(_("Could not initialize Bonobo\n"));
+
+  /*
+   * We can't make any CORBA calls unless we're in the main
+   * loop.  So we delay creating the container here.
+   */
+  gtk_idle_add ((GtkFunction) prepare_app, NULL);
+
+  bonobo_main();
 
-  /* main loop */
-  gtk_main();
   return (0);
 }
 
 /*
  * Callbacks
  */
-static void 
-about_cb (GtkWidget *w, gpointer data)
-{
-  const gchar *authors[] = { "Michael Lausch <michael@lausch.at>",
-                             "Rodrigo Moya <rmoya@chez.com>",
-                             "Stephan Heinze <stephan.heinze@xcom.de>",
-                             "Vivien Malerba <malerba@linuxbox.com>",
-                             NULL };
-  GtkWidget *about = gnome_about_new(_("GNOME-DB Builder"), VERSION,
-	     _("Copyright The Free Software Foundation (C) 1998-2000"),
-	     authors,
-             _("This program is part of the GNOME project for LINUX. "
-	       "GNOME Data Access comes with ABSOLUTELY NO WARRANTY. "
-	       "This is free software, and you are welcome to redistribute "
-	       "it under the conditions of the GNU General Public Licence."),
-	     "gnome-db.png");
-  gtk_widget_show(about);
-}
-
-static void 
-quit_cb (GtkWidget *w, gpointer data)
-{
-  gtk_main_quit();
-}
-
 static void
+run_app_cb (GtkWidget *w, const gchar *cmd)
+{
+  gchar* args[1];
+
+  g_return_if_fail(cmd != 0);
+
+  args[0] = cmd;
+  if (gnome_execute_async(NULL, 1, args) == -1)
+    gda_ui_show_error(_("Unable to execute '%s'"), args[0]);
+}
+
+static guint
 prepare_app (void)
 {
-  GtkWidget *pane;
-  
-  glb_App = gnome_app_new("gda-builder", "GDA Builder");
-  gtk_widget_realize(GTK_WIDGET(glb_App));
-  gtk_signal_connect(GTK_OBJECT(glb_App), "delete_event",
-		     GTK_SIGNAL_FUNC(quit_cb), NULL);
-  gtk_signal_connect(GTK_OBJECT(glb_App), "destroy",
-                     GTK_SIGNAL_FUNC(quit_cb), NULL);
+  GtkWidget* table;
+
+  glb_Container = gnome_db_container_new("gda-builder", mainmenu, toolbar, NULL);
+  gda_ui_load_window_config("MainWindow", gnome_db_container_get_toplevel(glb_Container));
+  gtk_signal_connect(GTK_OBJECT(glb_Container),
+		     "close",
+		     GTK_SIGNAL_FUNC(builder_quit_cb),
+		     NULL);
                   
   /* set main window contents */
-  gnome_app_create_toolbar(GNOME_APP(glb_App), toolbar);
-  
-  pane = gtk_hpaned_new();
-  gtk_widget_show(pane);
-  gnome_app_set_contents(GNOME_APP(glb_App), pane);
-  
-  gnome_app_create_menus(GNOME_APP(glb_App), mainmenu);
-     
-  /* create status bar */
-  glb_StatusBar = gnome_appbar_new(TRUE, TRUE, GNOME_PREFERENCES_USER);
-  gnome_appbar_set_default(GNOME_APPBAR(glb_StatusBar), _("Ready"));
-  gnome_app_set_statusbar(GNOME_APP(glb_App), glb_StatusBar);
-  gnome_app_install_menu_hints(GNOME_APP(glb_App), mainmenu);
-  
-  gtk_widget_show(glb_App);
+  table = gtk_table_new(4, 8, FALSE);
+  gtk_widget_show(table);
+  gnome_db_container_set_contents(glb_Container, table);
+
+  gtk_table_attach(GTK_TABLE(table),
+		   builder_project_window_open(),
+		   0, 2, 0, 4,
+		   GTK_FILL,
+		   GTK_FILL,
+		   3, 3);
+
+  glb_Notebook = gda_ui_new_notebook_widget();
+  gtk_table_attach(GTK_TABLE(table),
+		   glb_Notebook,
+		   2, 8, 0, 4,
+		   GTK_FILL | GTK_SHRINK | GTK_EXPAND,
+		   GTK_FILL | GTK_SHRINK | GTK_EXPAND,
+		   3, 3);
+
+  /* create default tabs */
+  gnome_db_container_show(glb_Container);
+  builder_help_window_open();
+
+  return FALSE;
 }
+
+
+
+
