@@ -22,21 +22,44 @@
 #if defined(HAVE_CONFIG_H)
 #  include <config.h>
 #endif
-
+#include <bonobo.h>
 #include <gda-ui.h>
+#include <gnome-db-container.h>
+
+/*
+ * UI callbacks
+ */
+extern void builder_about_cb           (GtkWidget *w, gpointer data);
+extern void builder_browse_database_cb (GtkWidget *w, gpointer data);
+extern void builder_quit_cb            (GtkWidget *w, gpointer data);
 
 /*
  * Database interface
  */
-extern void builder_database_connect    (GtkWidget *w, gpointer data);
-extern void builder_database_disconnect (GtkWidget *w, gpointer data);
+extern void builder_database_connect        (GtkWidget *w, gpointer data);
+extern void builder_database_disconnect     (GtkWidget *w, gpointer data);
+extern void builder_database_browse         (void);
+extern void builder_database_import_objects (GtkWidget *w, gpointer data);
+
+/*
+ * Project window
+ */
+extern GtkWidget* builder_project_window_open (void);
+extern void       builder_project_window_hide (void);
+extern void       builder_project_window_show (void);
+
+/*
+ * Help system
+ */
+extern void builder_help_window_open (void);
+extern void builder_help_goto        (const gchar *filename);
 
 /*
  * Global variables (defined in gda-builder-main.c)
  */
-extern GtkWidget*      glb_App;
-extern GtkWidget*      glb_StatusBar;
-extern CORBA_ORB       glb_Orb;
-extern Gda_Connection* glb_dbconn;
+extern GnomeDbContainer* glb_Container;
+extern GtkWidget*        glb_Notebook;
+extern CORBA_ORB         glb_Orb;
+extern Gda_Connection*   glb_dbconn;
 
-#endif
\ No newline at end of file
+#endif
