@@ -65,4 +65,22 @@ gda_mysql_error_make(Gda_MYSQL_Connection* cnc, gchar* where)
   
 }
 
+void
+gda_mysql_error_ours_make(Gda_MYSQL_Connection* cnc, gchar* where, gchar* desc)
+{
+  Gda_MYSQL_Error* error = gda_mysql_error_new();
+
+  g_warning("Error at '%s': ", where);
+  error->description = g_strdup(desc);
+  error->source = g_strdup("[GDA-MYSQL]");
+  error->helpfile = g_strdup("error");
+  error->helpctxt = g_strdup("error");
+  error->sqlstate = g_strdup("READY"); /* FIXME: is this okay? we caught this error in gda-mysql... - cdw */
+  error->native = g_strdup(error->description);
+  cnc->errors = g_list_append(cnc->errors, error);
+  g_warning("error->description = '%s'\n", error->description);
+  g_warning("   sqlstate = '%s'\n", error->sqlstate);
+  
+}
+
 		    
