@@ -21,8 +21,8 @@
 
 #include <glib.h>
 #include "gda.h"
-#include <mysql/mysql.h>
-#include <mysql/mysql_com.h>
+#include <mysql.h>
+#include <mysql_com.h>
 
 struct _Gda_MYSQL_Recordset;
 struct _Gda_MYSQL_Connection;
