@@ -33,12 +33,18 @@
 Gda_ODBC_Connection* gda_odbc_connection_new          (void);
 void                 gda_odbc_connection_free         (Gda_ODBC_Connection* cnc);
 gint                 gda_odbc_connection_close        (Gda_ODBC_Connection* cnc);
-Gda_ODBC_Recordset*  gda_odbc_connection_open_schema  (Gda_ODBC_Connection*       cnc,
-						       GDA_Connection_QType       t,
-						       GDA_Connection_Constraint* constraints,
-						       gint                       length);
+Gda_ODBC_Recordset*  gda_odbc_connection_open_schema  (Gda_ODBC_Connection* cnc,
+                                                       GDA_Connection_QType t,
+                                                       GDA_Connection_Constraint* constraints,
+                                                       gint length);
+
+gint                 gda_odbc_connection_open         (Gda_ODBC_Connection* cnc,
+                                                       const gchar* cnc_string,
+						                       const gchar* user,
+						                       const gchar* passwd);
+gchar*               gda_odbc_connection_create_recset(Gda_ODBC_Connection* cnc,
+                                                       GDA_RowAttributes* columns);
+gboolean             gda_odbc_connection_supports     (Gda_ODBC_Connection* cnc,
+                                                       GDA_Connection_Feature feature);
 
-gint                 gda_odbc_connection_open         (Gda_ODBC_Connection* cnc, const gchar* cnc_string,
-						       const gchar* user, const gchar* passwd);
-gchar*               gda_odbc_connection_create_recset(Gda_ODBC_Connection* cnc, GDA_RowAttributes* columns);
 #endif
