@@ -272,6 +272,11 @@ static CORBA_char *
 				 GDA_RowAttributes * columns,
 				 CORBA_Environment * ev);
 
+static CORBA_boolean
+ impl_GDA_Connection_supports (impl_POA_GDA_Connection *servant,
+                               GDA_Connection_Feature feature,
+                               CORBA_Environment *ev);
+
 static void impl_GDA_Recordset__destroy(impl_POA_GDA_Recordset * servant,
 					CORBA_Environment * ev);
 
@@ -539,6 +544,7 @@ static POA_GDA_Connection__epv impl_GDA_Connection_epv =
 
    (gpointer) & impl_GDA_Connection_createTable,
 
+   (gpointer) & impl_GDA_Connection_supports
 };
 
 static PortableServer_ServantBase__epv impl_GDA_Recordset_base_epv =
@@ -1308,6 +1314,13 @@ impl_GDA_Connection_createTable(impl_POA_GDA_Connection* servant,
   return retval;
 }
 
+static CORBA_boolean
+impl_GDA_Connection_supports (impl_POA_GDA_Connection* servant,
+                              GDA_Connection_Feature feature,
+                              CORBA_Environment *ev)
+{
+  return gda_odbc_connection_supports(servant->cnc, feature);
+}
 
 static GDA_Recordset 
 impl_GDA_Recordset__create(PortableServer_POA poa, Gda_ODBC_Recordset* rs, CORBA_Environment * ev)
@@ -1642,8 +1655,9 @@ impl_GDA_Recordset_fetch(impl_POA_GDA_Recordset * servant,
   GList*                 tmp_rows;
   gint                   rowlength;
 
+  fprintf(stderr,"impl_GDA_Recordset_fetch: enter\n");
   if (!servant->rs)
-    return GDA_Recordset_Chunk__alloc();	/* return empty chunk on error */
+    return CORBA_OBJECT_NIL;
 
   tmp_rows = 0;
   rowidx = 0;
@@ -1714,7 +1728,8 @@ impl_GDA_Recordset_fetch(impl_POA_GDA_Recordset * servant,
 	  field = &row->_buffer[++colidx];
 	}
       rowidx++;
-  } while (rowidx < count);
+  }while (rowidx < count);
+  fprintf(stderr,"After fetch loop\n");
   if (rc < 0)
     {
       GDA_DriverError*     exception = GDA_DriverError__alloc();
@@ -1725,7 +1740,7 @@ impl_GDA_Recordset_fetch(impl_POA_GDA_Recordset * servant,
       exception->errors._buffer = make_errorbuffer(cnc);
       exception->realcommand = CORBA_string_dup("Fetch");
       CORBA_exception_set(ev, CORBA_USER_EXCEPTION, ex_GDA_DriverError, exception);
-      return GDA_Recordset_Chunk__alloc();
+      return CORBA_OBJECT_NIL;
     }
   chunk = GDA_Recordset_Chunk__alloc();
   if (rowidx)
