@@ -361,7 +361,10 @@ gda_odbc_recset_move_prev(Gda_ODBC_Recordset* recset)
 	}
       l = g_list_next(l);
     }
-  rc = SQLFetchPrev(recset->hstmt);
+
+  rc = SQLExtendedFetch(recset->hstmt, SQL_FETCH_PRIOR,
+				  1, NULL, NULL );
+
   if (rc == SQL_NO_DATA_FOUND)
     {
       recset->at_end = 1;
