@@ -20,7 +20,7 @@ static CORBA_Object create_factory(PortableServer_POA poa, const gchar* goad_id,
 
 static void destroy_factory(PortableServer_POA poa, const gchar* goad_id, gpointer impl_ptr, CORBA_Environment* ev)
 {
-  impl_GDA_ConnectionFactory__destroy (poa, ev);
+  /*impl_GDA_ConnectionFactory__destroy (poa, ev);*/
 }
 
 
