@@ -750,7 +750,9 @@ schema_tables (Gda_POSTGRES_Error *error,
   g_string_append(query, " FROM pg_class a, pg_user b "
                   "WHERE ( relkind = 'r') and relname !~ '^pg_' "
                   "AND relname !~ '^xin[vx][0-9]+' AND "
-                  "b.usesysid = a.relowner ");
+                  "b.usesysid = a.relowner AND "
+		  "NOT (EXISTS (SELECT viewname FROM pg_views "
+		  "WHERE viewname=a.relname)) ");
   if (and_condition) 
     g_string_sprintfa(query, "%s", and_condition->str);
  
@@ -1097,23 +1099,29 @@ schema_views (Gda_POSTGRES_Error *error,
   cmd = gda_postgres_cmd_new();
   cmd->cnc = cnc;
   
-  /* build the query */
+  /* build the query: it is taken from the definition of pg_views and adapted
+     because oid can't be got from pg_views. */
   if (extra_info)
     {
       gchar *where_clause;
 
       if (view_name != 0)
         {
-          where_clause = g_strdup_printf("WHERE viewname = '%s'", view_name);
+          where_clause = g_strdup_printf("AND c.relname = '%s'", view_name);
         }
-      else where_clause = g_strdup(" ");
-      query = g_strdup_printf("SELECT viewname AS \"Name\", "
-                              "       viewowner AS \"Owner\", "
-                              "       obj_description(oid) AS \"Comments\", "
-                              "       definition AS \"SQL\" "
-                              " FROM pg_views "
-                              " %s "
-                              " ORDER BY viewname", where_clause);
+      else 
+	where_clause = g_strdup(" ");
+      query = g_strdup_printf("SELECT c.relname AS \"Name\", "
+			      "pg_get_userbyid(c.relowner) AS \"Owner\", "
+			      "obj_description(c.oid) as \"Comments\", "
+			      "pg_get_viewdef(c.relname) AS \"Definition\" "
+			      "FROM pg_class c WHERE (c.relhasrules AND "
+			      "(EXISTS (SELECT r.rulename FROM pg_rewrite "
+			      "r WHERE ((r.ev_class = c.oid) AND "
+			      "(r.ev_type = '1'::\"char\"))))) "
+			      "AND c.relname !~ '^pg_' AND "
+			      "c.relname !~ '^xin[vx][0-9]+' "
+			      "%s ORDER BY c.relname", where_clause);
       g_free((gpointer) where_clause);
     }
   else
@@ -1227,7 +1235,7 @@ gda_postgres_connection_open (Gda_POSTGRES_Connection *cnc, const gchar *dsn,
     {
       ptr_e = strchr(ptr_s, ';');
       if (ptr_e) *ptr_e = '\0';
-      if (strcasecmp(ptr_s, "HOST") == 0)
+      if (strncasecmp(ptr_s, "HOST", strlen("HOST")) == 0)
         cnc->pq_host = get_value(ptr_s);
       else if (strncasecmp(ptr_s, "DATABASE", strlen("DATABASE")) == 0)
         cnc->pq_db = get_value(ptr_s);
