@@ -625,7 +625,12 @@ fill_field_values (Gda_POSTGRES_Recordset *recset, glong row)
 
           /* get field's value from server */
 	  if(recset->pq_data)
-	    tmpstr = PQgetvalue(recset->pq_data, row, cnt);
+	    {
+	      if (PQgetisnull(recset->pq_data, row, cnt))
+		tmpstr = NULL;
+	      else
+		tmpstr = PQgetvalue(recset->pq_data, row, cnt);
+	    }
 	  else
 	    tmpstr = Gda_Builtin_Result_get_value(recset->btin_res, row, cnt);
 	  if (tmpstr)
@@ -642,11 +647,19 @@ fill_field_values (Gda_POSTGRES_Recordset *recset, glong row)
 	  switch (field->value->_d) 
 	    {
 	    case GDA_TypeBoolean:
-	      if (native_value && (*native_value=='t'))
-		field->value->_u.b = TRUE;
+	      if (native_value)
+		{
+		  if (*native_value=='t')
+		    field->value->_u.b = TRUE;
+		  else
+		    field->value->_u.b = FALSE;
+		  field->actual_length = sizeof(CORBA_boolean);
+		}
 	      else
-		field->value->_u.b = FALSE;
-	      field->actual_length = sizeof(CORBA_boolean);
+		{
+		    field->value->_u.b = FALSE;
+		    field->actual_length = 0;
+		}
 	      break;
 
 	    case GDA_TypeDbDate:
@@ -661,14 +674,15 @@ fill_field_values (Gda_POSTGRES_Recordset *recset, glong row)
 		      field->value->_u.dbd.month = stm->tm_mon + 1;
 		      field->value->_u.dbd.day = stm->tm_mday;
 		    }
+		  field->actual_length = sizeof(GDA_DbDate);
 		}
 	      if (!native_value || !stm)
 		{
 		  field->value->_u.dbd.year = 0;
 		  field->value->_u.dbd.month = 0;
 		  field->value->_u.dbd.day = 0;
+		  field->actual_length = 0;
 		}
-	      field->actual_length = sizeof(GDA_DbDate);
 	      if (stm)
 		g_free(stm);
 	      break;
@@ -684,14 +698,16 @@ fill_field_values (Gda_POSTGRES_Recordset *recset, glong row)
 		      field->value->_u.dbt.minute = stm->tm_min;
 		      field->value->_u.dbt.second = stm->tm_sec;
 		    }
+		  field->actual_length = sizeof(GDA_DbTime);
 		}
 	      if (!native_value || !stm)
 		{
 		  field->value->_u.dbt.hour = 0;
 		  field->value->_u.dbt.minute = 0;
 		  field->value->_u.dbt.second = 0;
+		  field->actual_length = 0;
 		}
-	      field->actual_length = sizeof(GDA_DbTime);
+
 	      if (stm)
 		g_free(stm);
 	      break;
@@ -710,6 +726,11 @@ fill_field_values (Gda_POSTGRES_Recordset *recset, glong row)
 	      field->value->_u.dbtstamp.minute = 0;
 	      field->value->_u.dbtstamp.second = 0;
 	      field->value->_u.dbtstamp.fraction = 0;
+	      if (! native_value)
+		{
+		  field->actual_length = 0;
+		  break;
+		}
 	      field->actual_length = sizeof(GDA_DbTimestamp);
 
 	      if ((field->sql_type == gda_postgres_connection_get_sql_type
@@ -717,8 +738,6 @@ fill_field_values (Gda_POSTGRES_Recordset *recset, glong row)
 		  (field->sql_type == gda_postgres_connection_get_sql_type
 		  (recset->cnc, "datetime")))
 		{
-		  if (!native_value)
-		    break;
 		  stm = str_to_tmstruct_abstime(native_value);
 
 		  if (!stm)
@@ -736,8 +755,6 @@ fill_field_values (Gda_POSTGRES_Recordset *recset, glong row)
 	      if (field->sql_type == gda_postgres_connection_get_sql_type
 		  (recset->cnc, "timestamp"))
 		{
-		  if (!native_value)
-		    break;
 		  stm = str_to_tmstruct_timestamp(native_value);
 
 		  if (!stm)
