@@ -273,6 +273,11 @@ static CORBA_char *
 				 GDA_RowAttributes * columns,
 				 CORBA_Environment * ev);
 
+static CORBA_boolean
+ impl_GDA_Connection_supports(impl_POA_GDA_Connection *servant,
+                              GDA_Connection_Feature feature,
+                              CORBA_Environment * ev);
+
 static void impl_GDA_Recordset__destroy(impl_POA_GDA_Recordset * servant,
 					CORBA_Environment * ev);
 
@@ -540,6 +545,7 @@ static POA_GDA_Connection__epv impl_GDA_Connection_epv =
 
    (gpointer) & impl_GDA_Connection_createTable,
 
+   (gpointer) & impl_GDA_Connection_supports
 };
 
 static PortableServer_ServantBase__epv impl_GDA_Recordset_base_epv =
@@ -970,9 +976,10 @@ impl_GDA_Command_open(impl_POA_GDA_Command * servant,
   Gda_POSTGRES_Recordset*      recset;
   Gda_POSTGRES_Error*          error;
   Gda_POSTGRES_Command*        cmd;
-
+  gulong                       laffected;
+  
   error = gda_postgres_error_new();
-  recset = gda_postgres_cmd_execute(servant->cmd, error, param, 0);
+  recset = gda_postgres_cmd_execute(servant->cmd, error, param, &laffected, 0);
   if (!recset)
     {
       if (error->description)
@@ -992,6 +999,7 @@ impl_GDA_Command_open(impl_POA_GDA_Command * servant,
       return CORBA_OBJECT_NIL;
     }
   gda_postgres_error_free(error);
+  *affected = laffected;
   retval = impl_GDA_Recordset__create(servant->poa, recset, ev);
   Exception_Function(ev);
   return retval;
@@ -1178,6 +1186,7 @@ impl_GDA_Connection_open(impl_POA_GDA_Connection * servant,
 			 CORBA_char * passwd,
 			 CORBA_Environment * ev)
 {
+  fprintf(stderr, "gda-postgres: opening connection with DSN: %s\n", dsn);
   if (gda_postgres_connection_open(servant->cnc, dsn, user, passwd) < 0)
     {
       GDA_DriverError* exception = GDA_DriverError__alloc();
@@ -1321,6 +1330,15 @@ impl_GDA_Connection_createTable(impl_POA_GDA_Connection * servant,
   return (retval);
 }
 
+static CORBA_boolean
+impl_GDA_Connection_supports (impl_POA_GDA_Connection * servant,
+                              GDA_Connection_Feature feature,
+                              CORBA_Environment *ev)
+{
+  return gda_postgres_connection_supports(servant->cnc, feature);
+}
+
+
 static GDA_Recordset 
 impl_GDA_Recordset__create(PortableServer_POA poa, Gda_POSTGRES_Recordset* recset, CORBA_Environment * ev)
 {
@@ -1578,6 +1596,7 @@ impl_GDA_Recordset_open(impl_POA_GDA_Recordset * servant,
   Gda_POSTGRES_Recordset* recset;
   Gda_POSTGRES_Command*    cmd;
   Gda_POSTGRES_Error*      error;
+  gulong                   laffected;
 
   fprintf(stderr,"gda_Recordset_open: text = '%s'\n", text);
   cmd = gda_postgres_cmd_new();
@@ -1585,7 +1604,8 @@ impl_GDA_Recordset_open(impl_POA_GDA_Recordset * servant,
   cmd->type = type;
   cmd->cnc = servant->recset->cnc;
   error = gda_postgres_error_new();
-  recset = gda_postgres_cmd_execute(cmd, error, param, 0);
+  /* FIXME: what to do with that affected parameter? */
+  recset = gda_postgres_cmd_execute(cmd, error, param, &laffected, 0);
   if (!recset)
     {
       if (error->description)
@@ -1772,6 +1792,8 @@ impl_GDA_Recordset_describe(impl_POA_GDA_Recordset * servant,
   Gda_POSTGRES_Field *server_field;
   GDA_FieldAttributes *field;
   gint idx;
+  GSList *repl_list;
+  Gda_POSTGRES_Recordset_Replacement *repl;
 
   rc = GDA_RowAttributes__alloc();
   rc->_length = g_list_length(rs->fields);
@@ -1784,15 +1806,35 @@ impl_GDA_Recordset_describe(impl_POA_GDA_Recordset * servant,
   while (ptr)
     {
       field = &rc->_buffer[idx];
-      server_field = ptr->data;
+      /* replacement stuff */
+      repl_list = rs->replacements;
+      repl = NULL;
+      while (repl_list && !repl)
+	{
+	  if (((Gda_POSTGRES_Recordset_Replacement *)(repl_list->data))
+	      ->colnum == idx)
+	    repl = (Gda_POSTGRES_Recordset_Replacement *)
+	      (repl_list->data);
+	  else
+	    repl_list = g_slist_next(repl_list);
+	}
+
+      server_field = (Gda_POSTGRES_Field *)(ptr->data);
       
       field->name        = CORBA_string_dup(server_field->name);
       fprintf(stderr,"gda_Recset_describe: sending field description for '%s'\n", field->name);
       field->definedSize = server_field->defined_length;
       
       field->scale       = server_field->num_scale;
-      field->gdaType     = GDA_TypeVarchar;
+      if (repl)
+	field->gdaType     = repl->newtype;
+      else
+	field->gdaType     = 
+	  gda_postgres_connection_get_gda_type(rs->cnc, 
+					       server_field->sql_type);
       field->nativeType  = server_field->sql_type;
+      field->cType = 
+	gda_postgres_connection_get_c_type_from_gda(rs->cnc, field->gdaType);
       ptr = g_list_next(ptr);
       idx++;
     }
