@@ -19,11 +19,7 @@
 
 
 #include <libgnorba/gnorba.h>
-#include "gda.h"
-#include "gda-connection.h"
-#include "gda-command.h"
-#include "gda-error.h"
-#include "gda-xml.h"
+#include <gda-client.h>
 
 gchar* provider = 0;
 gchar* database = 0;
